@@ -13,16 +13,16 @@ example on page 12 of the specification would in python look like this:
 
     context = vx.CreateContext()
     images = [
-        vx.CreateImage(context, 640, 480, vx.FOURCC_UYVY),
-        vx.CreateImage(context, 640, 480, vx.FOURCC_U8),
-        vx.CreateImage(context, 640, 480, vx.FOURCC_U8),
+        vx.CreateImage(context, 640, 480, vx.DF_IMAGE_UYVY),
+        vx.CreateImage(context, 640, 480, vx.DF_IMAGE_U8),
+        vx.CreateImage(context, 640, 480, vx.DF_IMAGE_U8),
     ]
     graph = vx.CreateGraph(context)
     virts = [
-        vx.CreateVirtualImage(graph, 0, 0, vx.FOURCC_VIRT),
-        vx.CreateVirtualImage(graph, 0, 0, vx.FOURCC_VIRT),
-        vx.CreateVirtualImage(graph, 0, 0, vx.FOURCC_VIRT),
-        vx.CreateVirtualImage(graph, 0, 0, vx.FOURCC_VIRT),
+        vx.CreateVirtualImage(graph, 0, 0, vx.DF_IMAGE_VIRT),
+        vx.CreateVirtualImage(graph, 0, 0, vx.DF_IMAGE_VIRT),
+        vx.CreateVirtualImage(graph, 0, 0, vx.DF_IMAGE_VIRT),
+        vx.CreateVirtualImage(graph, 0, 0, vx.DF_IMAGE_VIRT),
     ]
     vx.ChannelExtractNode(graph, images[0], vx.CHANNEL_Y, virts[0])
     vx.Gaussian3x3Node(graph, virts[0], virts[1])
@@ -43,8 +43,8 @@ example on page 12 of the specification would in python look like this:
 
 from pyvx.backend import CoreImage, Context
 from pyvx.optimize import OptimizedGraph
-from pyvx.types import *
 from pyvx.nodes import *
+from pyvx.inc.vx import *
 
 def CreateContext():
     return Context()
@@ -57,8 +57,8 @@ def CreateImage(context, width, height, color):
     return CoreImage(width, height, color, virtual=False, context=context)
 
 
-def CreateGraph(context):
-    return OptimizedGraph(context)
+def CreateGraph(context, early_verify=True):
+    return OptimizedGraph(context, early_verify)
 
 
 def CreateVirtualImage(graph, width, height, color):
